==> hlw-core-0.0.2-20250606.030359-46-sources.jar: cn/gtmap/hlw/core/dto/third/cqxx/HsxxInfoDTO.java <==
package cn.gtmap.hlw.core.dto.third.cqxx;

import lombok.Data;

/**
 * @author <a href="mailto:dingweiwei@gtmap.cn">dingweiwei</a>
 * @version 1.0, 2023/11/15
 * @description
 */
@Data
public class HsxxInfoDTO {
    /**
     * 逻辑幢主键
     */
    private String fwDcbIndex;
    /**
     * 户室主键
     */
    private String fwHsIndex;
    /**
     * 不动产单元号
     */
    private String bdcdyh;
    /**
     * 房屋编码
     */
    private String fwbm;
    /**
     * 物理层数
     */
    private String fwsjc;
    /**
     * 定义层数
     */
    private String dycs;
    /**
     * 物理层数
     */
    private String wlcs;
    /**
     * 房间号
     */
    private String fwfh;
    /**
     * 房间号
     */
    private String fjh;
    /**
     * 顺序号
     */
    private Integer sxh;
    /**
     * 坐落
     */
    private String zl;
    /**
     * 单元号
     */
    private String fwdyh;
    /**
     * 实测建筑面积
     */
    private Double jzmj;
    /**
     * 预测建筑面积
     */
    private Double ycjzmj;
    /**
     * 规划用途
     */
    private String ghyt;
    /**
     * 规划用途
     */
    private String ghytdm;
    /**
     * 房屋类型
     */
    private String fwlx;
    /**
     * 房屋性质
     */
    private String fwxz;
    /**
     * 房屋性质名称
     */
    private String fwxzmc;
    /**
     * 规划用途名称
     */
    private String ghytmc;
    /**
     * 房屋类型名称
     */
    private String fwlxmc;
    /**
     * 总层数
     */
    private Integer fwzcs;
    /**
     * 所在层
     */
    private String fwszc;
    /**
     * 房屋结构代码
     */
    private String fwjg;
    /**
     * 房屋结构名称
     */
    private String fwjgmc;
    /**
     * 土地所有权人
     */
    private String tdsyqr;
    /**
     * 宗地面积
     */
    private Double zdmj;
    /**
     * 权利性质代码
     */
    private String qlxzdm;
    /**
     * 权利性质名称
     */
    private String qlxzmc;
    /**
     * 宗地用途代码
     */
    private String zdytdm;
    /**
     * 宗地用途名称
     */
    private String zdytmc;
    /**
     * 土地使用起始时间
     */
    private String tdsyqssj;
    /**
     * 土地使用结束时间
     */
    private String tdsyjssj;
    private String houseid;
    /**
     * 首次登记证明号
     */
    private String scdjzmh;

    private String fwid;
    /**
     * 附记
     */
    private String fj;
    /**
     * 权籍关联代码
     */
    private String qjgldm;
    /**
     * 房屋土地信息
     */
    private HsxxTdxxDTO fwtdxx;

    /**
     * 竣工时间
     */
    private String jgsj;

    /**
     * 套内建筑面积
     */
    private Double tnjzmj;

    /**
     * 分摊建筑面积
     */
    private Double ftjzmj;

    /**
     * 分摊土地面积
     */
    private Double fttdmj;

    /**
     * 独用土地面积
     */
    private Double dytdmj;

    /**
     * 幢号
     */
    private String zrzh;
}

==> hlw-core-0.0.2-20251208.093710-177-sources.jar: cn/gtmap/hlw/core/dto/third/cqxx/HsxxInfoDTO.java <==
package cn.gtmap.hlw.core.dto.third.cqxx;

import cn.gtmap.hlw.core.annotation.ZdDzConfig;
import cn.gtmap.hlw.core.constant.dict.ZdTypeConstant;
import lombok.Data;

/**
 * @author <a href="mailto:dingweiwei@gtmap.cn">dingweiwei</a>
 * @version 1.0, 2023/11/15
 * @description
 */
@Data
public class HsxxInfoDTO {
    /**
     * 逻辑幢主键
     */
    private String fwDcbIndex;
    /**
     * 户室主键
     */
    private String fwHsIndex;
    /**
     * 不动产单元号
     */
    private String bdcdyh;
    /**
     * 房屋编码
     */
    private String fwbm;
    /**
     * 物理层数
     */
    private String fwsjc;
    /**
     * 定义层数
     */
    private String dycs;
    /**
     * 物理层数
     */
    private String wlcs;
    /**
     * 房间号
     */
    private String fwfh;
    /**
     * 房间号
     */
    private String fjh;
    /**
     * 顺序号
     */
    private Integer sxh;
    /**
     * 坐落
     */
    private String zl;
    /**
     * 单元号
     */
    private String fwdyh;
    /**
     * 实测建筑面积
     */
    private Double jzmj;
    /**
     * 预测建筑面积
     */
    private Double ycjzmj;
    /**
     * 规划用途
     */
    private String ghyt;
    /**
     * 规划用途
     */
    @ZdDzConfig(field = "ghytdm", tableName = ZdTypeConstant.ZD_TYPE_GHYT, dmToDm = true)
    private String ghytdm;
    /**
     * 房屋类型
     */
    private String fwlx;
    /**
     * 房屋性质
     */
    private String fwxz;
    /**
     * 房屋性质名称
     */
    private String fwxzmc;
    /**
     * 规划用途名称
     */
    @ZdDzConfig(field = "ghytdm", tableName = ZdTypeConstant.ZD_TYPE_GHYT, dmToMc = true)
    private String ghytmc;
    /**
     * 房屋类型名称
     */
    private String fwlxmc;
    /**
     * 总层数
     */
    private Integer fwzcs;
    /**
     * 所在层
     */
    private String fwszc;
    /**
     * 房屋结构代码
     */
    @ZdDzConfig(field = "fwjg", tableName = ZdTypeConstant.ZD_TYPE_FWJG, dmToDm = true)
    private String fwjg;
    /**
     * 房屋结构名称
     */
    @ZdDzConfig(field = "fwjg", tableName = ZdTypeConstant.ZD_TYPE_FWJG, dmToMc = true)
    private String fwjgmc;
    /**
     * 土地所有权人
     */
    private String tdsyqr;
    /**
     * 宗地面积
     */
    private Double zdmj;
    /**
     * 权利性质代码
     */
    private String qlxzdm;
    /**
     * 权利性质名称
     */
    private String qlxzmc;
    /**
     * 宗地用途代码
     */
    private String zdytdm;
    /**
     * 宗地用途名称
     */
    private String zdytmc;
    /**
     * 土地使用起始时间
     */
    private String tdsyqssj;
    /**
     * 土地使用结束时间
     */
    private String tdsyjssj;
    private String houseid;
    /**
     * 首次登记证明号
     */
    private String scdjzmh;

    private String fwid;
    /**
     * 附记
     */
    private String fj;
    /**
     * 权籍关联代码
     */
    private String qjgldm;
    /**
     * 房屋土地信息
     */
    private HsxxTdxxDTO fwtdxx;

    /**
     * 竣工时间
     */
    private String jgsj;

    /**
     * 套内建筑面积
     */
    private Double tnjzmj;

    /**
     * 分摊建筑面积
     */
    private Double ftjzmj;

    /**
     * 分摊土地面积
     */
    private Double fttdmj;

    /**
     * 独用土地面积
     */
    private Double dytdmj;

    /**
     * 幢号
     */
    private String zrzh;

    /**
     * 房屋幢号
     */
    private String fwzh;
}
